<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>MX Package Installer</source>
        <translation>MX Installateur de paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Applications populaires</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Package</source>
        <translation>Paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="989"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="626"/>
        <location filename="../mainwindow.ui" line="958"/>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Gestionnaire des paquets les plus recherchés&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Les paquets grisés ont déjà été installés.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Dépôt stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="903"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrer les paquets selon leur état.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="574"/>
        <location filename="../mainwindow.ui" line="578"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.ui" line="910"/>
        <location filename="../mainwindow.cpp" line="2305"/>
        <source>All packages</source>
        <translation>Tous les paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="583"/>
        <location filename="../mainwindow.ui" line="915"/>
        <location filename="../mainwindow.cpp" line="2319"/>
        <source>Installed</source>
        <translation>Installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="920"/>
        <location filename="../mainwindow.cpp" line="2317"/>
        <source>Upgradable</source>
        <translation>Mise à niveau possible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="593"/>
        <location filename="../mainwindow.ui" line="925"/>
        <location filename="../mainwindow.ui" line="1213"/>
        <location filename="../mainwindow.cpp" line="2284"/>
        <location filename="../mainwindow.cpp" line="2321"/>
        <location filename="../mainwindow.cpp" line="2410"/>
        <source>Not installed</source>
        <translation>Non installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="979"/>
        <source>Package Name</source>
        <translation>Nom du paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="984"/>
        <location filename="../mainwindow.ui" line="1268"/>
        <source>Version</source>
        <translation>Version </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="687"/>
        <location filename="../mainwindow.ui" line="1046"/>
        <source>Total packages:</source>
        <translation>Total des paquets:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="737"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <source>Installed:</source>
        <translation>Installés:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Upgradable:</source>
        <translation>Pouvant être mis à niveau:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.ui" line="1338"/>
        <source>Upgrade All</source>
        <translation>Tout mettre à niveau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <location filename="../mainwindow.ui" line="701"/>
        <location filename="../mainwindow.ui" line="1053"/>
        <source>Hide library and developer packages</source>
        <translation>Masquer les paquets pour développeurs et de bibliothèque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <location filename="../mainwindow.ui" line="723"/>
        <location filename="../mainwindow.ui" line="1105"/>
        <source>Refresh list</source>
        <translation>Rafraîchir la liste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="1086"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="424"/>
        <location filename="../mainwindow.ui" line="601"/>
        <location filename="../mainwindow.ui" line="933"/>
        <location filename="../mainwindow.ui" line="1481"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Les paquets grisés ont déjà été installés.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <location filename="../mainwindow.ui" line="543"/>
        <location filename="../mainwindow.ui" line="870"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Paquet pouvant être mis à niveau. Une nouvelle version est disponible dans le dépôt sélectionné.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>MX Test Repo</source>
        <translation>Dépôt de test MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="827"/>
        <source>Debian Backports</source>
        <translation>Dépôt de rétroportages Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1160"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2265"/>
        <source>All apps</source>
        <translation>Toutes les applications</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1193"/>
        <location filename="../mainwindow.cpp" line="2270"/>
        <source>All runtimes</source>
        <translation>Tous les environnements d&apos;exécution </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1198"/>
        <location filename="../mainwindow.cpp" line="2275"/>
        <source>All available</source>
        <translation>Total disponible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1203"/>
        <location filename="../mainwindow.cpp" line="2263"/>
        <location filename="../mainwindow.cpp" line="2405"/>
        <source>Installed apps</source>
        <translation>Applications installées</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1208"/>
        <location filename="../mainwindow.cpp" line="2261"/>
        <source>Installed runtimes</source>
        <translation>Environnements d&apos;exécution installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1258"/>
        <source>Short Name</source>
        <translation>Abréviation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1263"/>
        <source>Full Package Name</source>
        <translation>Nom complet du paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1273"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Total items </source>
        <translation>Nombre d&apos;objets total</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1331"/>
        <source>Installed apps:</source>
        <translation>Applications installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1384"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1414"/>
        <source>Total installed size:</source>
        <translation>Taille totale installée</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1431"/>
        <location filename="../mainwindow.ui" line="1435"/>
        <source>For all users</source>
        <translation>Pour tous les utilisateurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1440"/>
        <source>For current user</source>
        <translation>Pour l&apos;utilisateur actuel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Remote (repo):</source>
        <translation>Dépôt à distance (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="2092"/>
        <location filename="../mainwindow.cpp" line="2218"/>
        <source>Console Output</source>
        <translation>Données de sortie de la console</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>Enter</source>
        <translation>Entrer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1518"/>
        <source>Respond here, or just press Enter</source>
        <translation>Répondez ici, ou appuyez sur Entrée</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Uninstall</source>
        <translation>Désinstaller</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1581"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1597"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1600"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1607"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1655"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Help</source>
        <translation>Aide </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1665"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1681"/>
        <location filename="../mainwindow.cpp" line="992"/>
        <location filename="../mainwindow.cpp" line="1980"/>
        <location filename="../mainwindow.cpp" line="2399"/>
        <location filename="../mainwindow.cpp" line="2402"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1688"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1707"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1717"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Uninstalling packages...</source>
        <translation>Désinstallation des paquets...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Running post-uninstall operations...</source>
        <translation>Processus post-désinstallation en cours...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="182"/>
        <source>Refreshing sources...</source>
        <translation>Rafraîchissement des sources...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="1027"/>
        <location filename="../mainwindow.cpp" line="1154"/>
        <location filename="../mainwindow.cpp" line="1270"/>
        <location filename="../mainwindow.cpp" line="1883"/>
        <location filename="../mainwindow.cpp" line="1910"/>
        <location filename="../mainwindow.cpp" line="1920"/>
        <location filename="../mainwindow.cpp" line="2063"/>
        <location filename="../mainwindow.cpp" line="2083"/>
        <location filename="../mainwindow.cpp" line="2489"/>
        <location filename="../mainwindow.cpp" line="2565"/>
        <location filename="../mainwindow.cpp" line="2592"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Un problème a été rencontré lors de la mise à jour des sources. Certaines sources n&apos;ont pas pu fournir de mises à jour. Pour plus d&apos;informations analysez:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>Please wait...</source>
        <translation>Veuillez patienter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="757"/>
        <location filename="../mainwindow.cpp" line="775"/>
        <source>Version </source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="757"/>
        <source> in stable repo</source>
        <translation>dans le dépôt stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Not available in stable repo</source>
        <translation>Non disponible dans le dépôt stable </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <location filename="../mainwindow.cpp" line="2198"/>
        <source>Latest version </source>
        <translation>Version la plus récente </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <location filename="../mainwindow.cpp" line="2198"/>
        <source> already installed</source>
        <translation>déjà installée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="775"/>
        <source> installed</source>
        <translation>installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="886"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Vous allez utiliser le dépôt de test MX dont les paquets sont fournis uniquement à des fins de test. Ils peuvent potentiellement casser votre système, aussi nous vous suggérons d&apos;en faire une copie de sauvegarde et d&apos;installer ou de mettre à jour un seul paquet à la fois. N&apos;hésitez pas à nous faire un retour via le forum afin que les paquets soient évalués avant d&apos;être transférés dans les dépôts principaux.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="895"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Vous êtes sur le point d&apos;utiliser le dépôt de rétroportage (Backports) de Debian. Il contient des paquets provenant de la prochaine version de Debian (appelée &apos;testing&apos;) qui ont été modifiés et recompilés pour être utilisés dans Debian &apos;stable&apos;. Par conséquent, ils n&apos;ont pas pu faire l&apos;objet de tests aussi poussés que pour les versions stables de Debian et de MX Linux et peuvent présenter des incompatibilités avec d&apos;autres composants de Debian &apos;stable&apos;. À utiliser avec précaution!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="903"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux inclut ce dépôt de flatpaks par commodité pour les utilisateurs, mais n&apos;est pas responsable de leur bon fonctionnement. Pour plus d&apos;informations, consultez flatpaks dans le Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="916"/>
        <source>Do not show this message again</source>
        <translation>Ne plus afficher ce message</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="989"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Les packages suivants ont été sélectionnés. Cliquez sur Afficher les détails pour obtenir la liste des modifications.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1027"/>
        <location filename="../mainwindow.cpp" line="1154"/>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet est indisponible, le téléchargement de la liste des paquets est impossible</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1032"/>
        <source>Installing packages...</source>
        <translation>Installation des paquets...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1084"/>
        <source>Post-processing...</source>
        <translation>Post-traitement...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1116"/>
        <source>Pre-processing for </source>
        <translation>Pré-traitement pour</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1129"/>
        <source>Installing </source>
        <translation>Installation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1136"/>
        <source>Post-processing for </source>
        <translation>Post-traitement pour</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1277"/>
        <source>Downloading package info...</source>
        <translation>Téléchargement des infos des paquets...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1723"/>
        <source>Packages to be installed: </source>
        <translation>Paquets à installer:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Package info</source>
        <translation>Informations sur le paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1879"/>
        <location filename="../mainwindow.cpp" line="1891"/>
        <location filename="../mainwindow.cpp" line="1904"/>
        <location filename="../mainwindow.cpp" line="1917"/>
        <location filename="../mainwindow.cpp" line="2036"/>
        <location filename="../mainwindow.cpp" line="2058"/>
        <location filename="../mainwindow.cpp" line="2485"/>
        <location filename="../mainwindow.cpp" line="2559"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1879"/>
        <location filename="../mainwindow.cpp" line="1891"/>
        <location filename="../mainwindow.cpp" line="1904"/>
        <location filename="../mainwindow.cpp" line="1917"/>
        <location filename="../mainwindow.cpp" line="2036"/>
        <location filename="../mainwindow.cpp" line="2058"/>
        <location filename="../mainwindow.cpp" line="2076"/>
        <location filename="../mainwindow.cpp" line="2485"/>
        <location filename="../mainwindow.cpp" line="2559"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <source>Processing finished successfully.</source>
        <translation>Processus achevé avec succès.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1883"/>
        <location filename="../mainwindow.cpp" line="1910"/>
        <location filename="../mainwindow.cpp" line="1920"/>
        <location filename="../mainwindow.cpp" line="2489"/>
        <location filename="../mainwindow.cpp" line="2565"/>
        <location filename="../mainwindow.cpp" line="2592"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Un problème a été détecté pendant l&apos;installation, veuillez examiner les données de sortie de la console </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1930"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1935"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1949"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">À propos de MX Installateur de paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1931"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1932"/>
        <source>Package Installer for MX Linux</source>
        <translation>Installateur de paquets pour MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1934"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licence</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Journal des modifications</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1978"/>
        <source>Reinstall</source>
        <translation>Réinstaller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2063"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Problème rencontré durant la désinstallation. Vérifiez la sortie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2076"/>
        <source>Success</source>
        <translation>Réussite de l&apos;installation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2083"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Un problème a été rencontré lors de la désinstallation du programme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2174"/>
        <location filename="../mainwindow.cpp" line="2185"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak n&apos;est pas installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2174"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak n&apos;est pas installé actuellement.
OK pour continuer et l&apos;installer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2185"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak n&apos;a pas été installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2206"/>
        <location filename="../mainwindow.cpp" line="2225"/>
        <source>Flathub remote failed</source>
        <translation>Dépôt à distance Flathub échoué</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2206"/>
        <location filename="../mainwindow.cpp" line="2225"/>
        <source>Flathub remote could not be added</source>
        <translation>Le dépôt à distance Flathub n&apos;a pas pu être ajouté.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2214"/>
        <source>Needs re-login</source>
        <translation>Reconnexion requise</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2214"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Vous pourriez devoir vous déconnecter/reconnecter pour voir les objets installés dans le menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2397"/>
        <source>Upgrade</source>
        <translation>Mettre à niveau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2519"/>
        <source>Quit?</source>
        <translation>Quitter?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2520"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Processus toujours en cours, quitter maintenant pourrait laisser le système en état d&apos;instabilité .&lt;p&gt;&lt;b&gt;Êtes-vous sur de vouloir quitter l&apos;installateur de paquets MX ?&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gérer les dépôts à distance Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Pour tous les utilisateurs</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Pour l&apos;utilisateur actuel</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>Entrez URL du dépôt à distance Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>Entrez la location Flatpakref pour installer l&apos;application</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Ajouter ou supprimer dépôts à distance flatpak (dépôts), ou installer des applications via l&apos;URL ou le chemin flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Supprimer dépôt à distance</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Ajouter dépôt à distance</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Installer l&apos;application</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Ne peut être supprimé</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub est le principal dépôt à distance Flatpak et ne sera pas supprimé</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation>Erreur durant l&apos;ajout du dépôt à distance</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Le dépôt à distance n&apos;a pas pu être ajouté - la commande a diagnostiqué une erreur. Vérifiez attentivement l&apos;adresse du dépôt à distance et essayez à nouveau</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Réussite de l&apos;installation</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>Dépôt à distance ajouté avec succès</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Unable to get exclusive lock</source>
        <translation>Impossible d&apos;obtenir le verrou exclusif</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Une autre application de gestion des paquets (comme Synaptic ou apt-get) est déjà en cours d&apos;exécution. Veuillez d&apos;abord fermer cette application.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You must run this program as root.</source>
        <translation>Vous devez lancer cette application avec les droits administrateur.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fermer</translation>
    </message>
</context>
</TS>
